@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 
@@ -7,4 +7,4 @@ class BindComplete(BackendMessage):
     pass
 
 
-BindComplete._message_id('2')
+BindComplete._message_id(b'2')
