@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 
@@ -7,4 +7,4 @@ class NoData(BackendMessage):
     pass
 
 
-NoData._message_id('n')
+NoData._message_id(b'n')
